.. image:: https://secure.travis-ci.org/yourlabs/django-autocomplete-light.png?branch=master

This is a simple alternative to django-ajax-selects.

Requirements
------------

Python 2.7
jQuery 1.7+
Django 1.4+ (at least for autocomplete_light.forms helpers)
django.contrib.staticfiles or you're on your own

Resources
---------

Documentation graciously hosted by RTFD:
http://django-autocomplete-light.rtfd.org

Continuous integration graciously hosted by Travis:
http://travis-ci.org/yourlabs/django-autocomplete-light

Git graciously hosted by GitHub:
https://github.com/yourlabs/django-autocomplete-light/

Package graciously hosted by PyPi:
http://pypi.python.org/pypi/django-autocomplete-light/

Demo
----

See test_project/README
